@@ -21,6 +21,7 @@
  */
 #include "config.h"
 
+#include <glib/gi18n.h>
 #include <gtk/gtk.h>
 
 typedef void (*ActionInvokedCb) (GtkWindow* nw, const char* key);
@@ -751,7 +752,7 @@ GtkWindow* create_notification(UrlClickedCb url_clicked)
 #endif
 
 	atkobj = gtk_widget_get_accessible(windata->summary_label);
-	atk_object_set_description(atkobj, "Notification summary text.");
+	atk_object_set_description (atkobj, _("Notification summary text."));
 
 	/* Add the close button */
 	alignment = gtk_alignment_new(1, 0, 0, 0);
@@ -775,9 +776,10 @@ GtkWindow* create_notification(UrlClickedCb url_clicked)
 #endif
 
 	atkobj = gtk_widget_get_accessible(close_button);
-	atk_action_set_description(ATK_ACTION(atkobj), 0, "Closes the notification.");
+	atk_action_set_description(ATK_ACTION(atkobj), 0,
+                               _("Closes the notification."));
 	atk_object_set_name(atkobj, "");
-	atk_object_set_description(atkobj, "Closes the notification.");
+	atk_object_set_description (atkobj, _("Closes the notification."));
 
 	image = gtk_image_new_from_icon_name ("window-close", GTK_ICON_SIZE_MENU);
 	gtk_widget_show(image);
@@ -820,7 +822,7 @@ GtkWindow* create_notification(UrlClickedCb url_clicked)
 	g_signal_connect(G_OBJECT(windata->body_label), "activate-link", G_CALLBACK(activate_link), windata);
 
 	atkobj = gtk_widget_get_accessible(windata->body_label);
-	atk_object_set_description(atkobj, "Notification body text.");
+	atk_object_set_description (atkobj, _("Notification body text."));
 
 	alignment = gtk_alignment_new(1, 0.5, 0, 0);
 	gtk_widget_show(alignment);
